==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/list_term_tenant_css_cluster_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTermTenantCssClusterResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'css_clusters': 'list[TermTenantCssClusterDto]',
        'count': 'int'
    }

    attribute_map = {
        'css_clusters': 'css_clusters',
        'count': 'count'
    }

    def __init__(self, css_clusters=None, count=None):
        """ListTermTenantCssClusterResponse

        The model defined in huaweicloud sdk

        :param css_clusters: 最终租户CSS集群列表
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.TermTenantCssClusterDto`]
        :param count: 最终租户css集群总数
        :type count: int
        """
        
        super(ListTermTenantCssClusterResponse, self).__init__()

        self._css_clusters = None
        self._count = None
        self.discriminator = None

        if css_clusters is not None:
            self.css_clusters = css_clusters
        if count is not None:
            self.count = count

    @property
    def css_clusters(self):
        """Gets the css_clusters of this ListTermTenantCssClusterResponse.

        最终租户CSS集群列表

        :return: The css_clusters of this ListTermTenantCssClusterResponse.
        :rtype: list[:class:`huaweicloudsdkeihealth.v1.TermTenantCssClusterDto`]
        """
        return self._css_clusters

    @css_clusters.setter
    def css_clusters(self, css_clusters):
        """Sets the css_clusters of this ListTermTenantCssClusterResponse.

        最终租户CSS集群列表

        :param css_clusters: The css_clusters of this ListTermTenantCssClusterResponse.
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.TermTenantCssClusterDto`]
        """
        self._css_clusters = css_clusters

    @property
    def count(self):
        """Gets the count of this ListTermTenantCssClusterResponse.

        最终租户css集群总数

        :return: The count of this ListTermTenantCssClusterResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListTermTenantCssClusterResponse.

        最终租户css集群总数

        :param count: The count of this ListTermTenantCssClusterResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTermTenantCssClusterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.150-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/list_term_tenant_css_cluster_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTermTenantCssClusterResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'css_clusters': 'list[TermTenantCssClusterDto]',
        'count': 'int'
    }

    attribute_map = {
        'css_clusters': 'css_clusters',
        'count': 'count'
    }

    def __init__(self, css_clusters=None, count=None):
        r"""ListTermTenantCssClusterResponse

        The model defined in huaweicloud sdk

        :param css_clusters: 最终租户CSS集群列表
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.TermTenantCssClusterDto`]
        :param count: 最终租户css集群总数
        :type count: int
        """
        
        super(ListTermTenantCssClusterResponse, self).__init__()

        self._css_clusters = None
        self._count = None
        self.discriminator = None

        if css_clusters is not None:
            self.css_clusters = css_clusters
        if count is not None:
            self.count = count

    @property
    def css_clusters(self):
        r"""Gets the css_clusters of this ListTermTenantCssClusterResponse.

        最终租户CSS集群列表

        :return: The css_clusters of this ListTermTenantCssClusterResponse.
        :rtype: list[:class:`huaweicloudsdkeihealth.v1.TermTenantCssClusterDto`]
        """
        return self._css_clusters

    @css_clusters.setter
    def css_clusters(self, css_clusters):
        r"""Sets the css_clusters of this ListTermTenantCssClusterResponse.

        最终租户CSS集群列表

        :param css_clusters: The css_clusters of this ListTermTenantCssClusterResponse.
        :type css_clusters: list[:class:`huaweicloudsdkeihealth.v1.TermTenantCssClusterDto`]
        """
        self._css_clusters = css_clusters

    @property
    def count(self):
        r"""Gets the count of this ListTermTenantCssClusterResponse.

        最终租户css集群总数

        :return: The count of this ListTermTenantCssClusterResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListTermTenantCssClusterResponse.

        最终租户css集群总数

        :param count: The count of this ListTermTenantCssClusterResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTermTenantCssClusterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
